.. AIModelShare documentation master file, created by
   sphinx-quickstart on Sun Feb  6 18:05:24 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to AIModelShare's documentation!
========================================

Installing the Library
---------------------- 

Download the AIModelShare library from PyPI: :: 

	#install aimodelshare library
	! pip install aimodelshare

To fully utilize the library functionality, you will need to set up credentials on the `AI Model Share website <https://www.modelshare.org/login>`_ and with `Amazon Web Services <https://aws.amazon.com/free>`_

AI Model Share Tutorial
-----------------------
.. toctree::

   gettingstarted

AI Model Share Example Notebooks
--------------------------------
.. toctree::

   example_notebooks

AI Model Share Classes
----------------------
.. toctree::

   modelplayground
   competition


AI Model Share Supporting Functions 
-----------------------------------
.. toctree::

   functions

AI Model Share Advanced Features 
--------------------------------
.. toctree::

   advanced_features

About Us
---------
.. toctree::

   about


.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

License
-------
AI | Model Share - All rights reserved. `Terms of Service <https://www.modelshare.org/terms-of-service>`_ and `Privacy Policy. <https://www.modelshare.org/privacy-policy>`_
